# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .abstract_data_operation_config import AbstractDataOperationConfig
from .abstract_field import AbstractField
from .abstract_format_attribute import AbstractFormatAttribute
from .abstract_frequency_details import AbstractFrequencyDetails
from .abstract_read_attribute import AbstractReadAttribute
from .abstract_write_attribute import AbstractWriteAttribute
from .aggregator import Aggregator
from .aggregator_summary import AggregatorSummary
from .application import Application
from .application_details import ApplicationDetails
from .application_summary import ApplicationSummary
from .application_summary_collection import ApplicationSummaryCollection
from .auth_details import AuthDetails
from .avro_format_attribute import AvroFormatAttribute
from .base_type import BaseType
from .bicc_read_attributes import BiccReadAttributes
from .change_compartment_details import ChangeCompartmentDetails
from .child_reference import ChildReference
from .child_reference_detail import ChildReferenceDetail
from .composite_field_map import CompositeFieldMap
from .composite_type import CompositeType
from .compression import Compression
from .conditional_input_link import ConditionalInputLink
from .config_definition import ConfigDefinition
from .config_parameter_definition import ConfigParameterDefinition
from .config_parameter_value import ConfigParameterValue
from .config_provider import ConfigProvider
from .config_values import ConfigValues
from .configuration_details import ConfigurationDetails
from .configured_type import ConfiguredType
from .connection import Connection
from .connection_details import ConnectionDetails
from .connection_from_adwc import ConnectionFromAdwc
from .connection_from_adwc_details import ConnectionFromAdwcDetails
from .connection_from_amazon_s3 import ConnectionFromAmazonS3
from .connection_from_amazon_s3_details import ConnectionFromAmazonS3Details
from .connection_from_atp import ConnectionFromAtp
from .connection_from_atp_details import ConnectionFromAtpDetails
from .connection_from_bicc import ConnectionFromBICC
from .connection_from_bicc_details import ConnectionFromBICCDetails
from .connection_from_jdbc import ConnectionFromJdbc
from .connection_from_jdbc_details import ConnectionFromJdbcDetails
from .connection_from_my_sql import ConnectionFromMySQL
from .connection_from_my_sql_details import ConnectionFromMySQLDetails
from .connection_from_object_storage import ConnectionFromObjectStorage
from .connection_from_object_storage_details import ConnectionFromObjectStorageDetails
from .connection_from_oracle import ConnectionFromOracle
from .connection_from_oracle_details import ConnectionFromOracleDetails
from .connection_property import ConnectionProperty
from .connection_summary import ConnectionSummary
from .connection_summary_collection import ConnectionSummaryCollection
from .connection_summary_from_adwc import ConnectionSummaryFromAdwc
from .connection_summary_from_amazon_s3 import ConnectionSummaryFromAmazonS3
from .connection_summary_from_atp import ConnectionSummaryFromAtp
from .connection_summary_from_bicc import ConnectionSummaryFromBICC
from .connection_summary_from_jdbc import ConnectionSummaryFromJdbc
from .connection_summary_from_my_sql import ConnectionSummaryFromMySQL
from .connection_summary_from_object_storage import ConnectionSummaryFromObjectStorage
from .connection_summary_from_oracle import ConnectionSummaryFromOracle
from .connection_validation import ConnectionValidation
from .connection_validation_summary import ConnectionValidationSummary
from .connection_validation_summary_collection import ConnectionValidationSummaryCollection
from .connector_attribute import ConnectorAttribute
from .count_statistic import CountStatistic
from .count_statistic_summary import CountStatisticSummary
from .create_application_details import CreateApplicationDetails
from .create_config_provider import CreateConfigProvider
from .create_connection_details import CreateConnectionDetails
from .create_connection_from_adwc import CreateConnectionFromAdwc
from .create_connection_from_amazon_s3 import CreateConnectionFromAmazonS3
from .create_connection_from_atp import CreateConnectionFromAtp
from .create_connection_from_bicc import CreateConnectionFromBICC
from .create_connection_from_jdbc import CreateConnectionFromJdbc
from .create_connection_from_my_sql import CreateConnectionFromMySQL
from .create_connection_from_object_storage import CreateConnectionFromObjectStorage
from .create_connection_from_oracle import CreateConnectionFromOracle
from .create_connection_validation_details import CreateConnectionValidationDetails
from .create_data_asset_details import CreateDataAssetDetails
from .create_data_asset_from_adwc import CreateDataAssetFromAdwc
from .create_data_asset_from_amazon_s3 import CreateDataAssetFromAmazonS3
from .create_data_asset_from_atp import CreateDataAssetFromAtp
from .create_data_asset_from_fusion_app import CreateDataAssetFromFusionApp
from .create_data_asset_from_jdbc import CreateDataAssetFromJdbc
from .create_data_asset_from_my_sql import CreateDataAssetFromMySQL
from .create_data_asset_from_object_storage import CreateDataAssetFromObjectStorage
from .create_data_asset_from_oracle import CreateDataAssetFromOracle
from .create_data_flow_details import CreateDataFlowDetails
from .create_data_flow_validation_details import CreateDataFlowValidationDetails
from .create_entity_shape_details import CreateEntityShapeDetails
from .create_entity_shape_from_file import CreateEntityShapeFromFile
from .create_external_publication_details import CreateExternalPublicationDetails
from .create_external_publication_validation_details import CreateExternalPublicationValidationDetails
from .create_folder_details import CreateFolderDetails
from .create_patch_details import CreatePatchDetails
from .create_pipeline_details import CreatePipelineDetails
from .create_pipeline_validation_details import CreatePipelineValidationDetails
from .create_project_details import CreateProjectDetails
from .create_schedule_details import CreateScheduleDetails
from .create_source_application_info import CreateSourceApplicationInfo
from .create_task_details import CreateTaskDetails
from .create_task_from_data_loader_task import CreateTaskFromDataLoaderTask
from .create_task_from_integration_task import CreateTaskFromIntegrationTask
from .create_task_from_oci_dataflow_task import CreateTaskFromOCIDataflowTask
from .create_task_from_pipeline_task import CreateTaskFromPipelineTask
from .create_task_from_rest_task import CreateTaskFromRestTask
from .create_task_from_sql_task import CreateTaskFromSQLTask
from .create_task_run_details import CreateTaskRunDetails
from .create_task_schedule_details import CreateTaskScheduleDetails
from .create_task_validation_details import CreateTaskValidationDetails
from .create_task_validation_from_data_loader_task import CreateTaskValidationFromDataLoaderTask
from .create_task_validation_from_integration_task import CreateTaskValidationFromIntegrationTask
from .create_task_validation_from_pipeline_task import CreateTaskValidationFromPipelineTask
from .create_workspace_details import CreateWorkspaceDetails
from .csv_format_attribute import CsvFormatAttribute
from .daily_frequency_details import DailyFrequencyDetails
from .data_asset import DataAsset
from .data_asset_from_adwc_details import DataAssetFromAdwcDetails
from .data_asset_from_amazon_s3 import DataAssetFromAmazonS3
from .data_asset_from_atp_details import DataAssetFromAtpDetails
from .data_asset_from_fusion_app import DataAssetFromFusionApp
from .data_asset_from_jdbc import DataAssetFromJdbc
from .data_asset_from_my_sql import DataAssetFromMySQL
from .data_asset_from_object_storage_details import DataAssetFromObjectStorageDetails
from .data_asset_from_oracle_details import DataAssetFromOracleDetails
from .data_asset_summary import DataAssetSummary
from .data_asset_summary_collection import DataAssetSummaryCollection
from .data_asset_summary_from_adwc import DataAssetSummaryFromAdwc
from .data_asset_summary_from_amazon_s3 import DataAssetSummaryFromAmazonS3
from .data_asset_summary_from_atp import DataAssetSummaryFromAtp
from .data_asset_summary_from_fusion_app import DataAssetSummaryFromFusionApp
from .data_asset_summary_from_jdbc import DataAssetSummaryFromJdbc
from .data_asset_summary_from_my_sql import DataAssetSummaryFromMySQL
from .data_asset_summary_from_object_storage import DataAssetSummaryFromObjectStorage
from .data_asset_summary_from_oracle import DataAssetSummaryFromOracle
from .data_entity import DataEntity
from .data_entity_details import DataEntityDetails
from .data_entity_from_data_store import DataEntityFromDataStore
from .data_entity_from_data_store_entity_details import DataEntityFromDataStoreEntityDetails
from .data_entity_from_file import DataEntityFromFile
from .data_entity_from_file_entity_details import DataEntityFromFileEntityDetails
from .data_entity_from_table import DataEntityFromTable
from .data_entity_from_table_entity_details import DataEntityFromTableEntityDetails
from .data_entity_from_view import DataEntityFromView
from .data_entity_from_view_entity_details import DataEntityFromViewEntityDetails
from .data_entity_summary import DataEntitySummary
from .data_entity_summary_collection import DataEntitySummaryCollection
from .data_entity_summary_from_data_store import DataEntitySummaryFromDataStore
from .data_entity_summary_from_file import DataEntitySummaryFromFile
from .data_entity_summary_from_table import DataEntitySummaryFromTable
from .data_entity_summary_from_view import DataEntitySummaryFromView
from .data_flow import DataFlow
from .data_flow_details import DataFlowDetails
from .data_flow_summary import DataFlowSummary
from .data_flow_summary_collection import DataFlowSummaryCollection
from .data_flow_validation import DataFlowValidation
from .data_flow_validation_summary import DataFlowValidationSummary
from .data_flow_validation_summary_collection import DataFlowValidationSummaryCollection
from .data_format import DataFormat
from .data_type import DataType
from .dataflow_application import DataflowApplication
from .dependent_object import DependentObject
from .dependent_object_summary import DependentObjectSummary
from .dependent_object_summary_collection import DependentObjectSummaryCollection
from .derived_field import DerivedField
from .derived_type import DerivedType
from .direct_field_map import DirectFieldMap
from .direct_named_field_map import DirectNamedFieldMap
from .distinct import Distinct
from .dynamic_input_field import DynamicInputField
from .dynamic_proxy_field import DynamicProxyField
from .dynamic_type import DynamicType
from .dynamic_type_handler import DynamicTypeHandler
from .end_operator import EndOperator
from .enriched_entity import EnrichedEntity
from .entity_shape import EntityShape
from .entity_shape_from_file import EntityShapeFromFile
from .error_details import ErrorDetails
from .expression import Expression
from .expression_operator import ExpressionOperator
from .external_publication import ExternalPublication
from .external_publication_summary import ExternalPublicationSummary
from .external_publication_summary_collection import ExternalPublicationSummaryCollection
from .external_publication_validation import ExternalPublicationValidation
from .external_publication_validation_summary import ExternalPublicationValidationSummary
from .external_publication_validation_summary_collection import ExternalPublicationValidationSummaryCollection
from .external_storage import ExternalStorage
from .field_map import FieldMap
from .filter import Filter
from .filter_push import FilterPush
from .flow_node import FlowNode
from .flow_port import FlowPort
from .flow_port_link import FlowPortLink
from .folder import Folder
from .folder_details import FolderDetails
from .folder_summary import FolderSummary
from .folder_summary_collection import FolderSummaryCollection
from .foreign_key import ForeignKey
from .hourly_frequency_details import HourlyFrequencyDetails
from .input_field import InputField
from .input_link import InputLink
from .input_port import InputPort
from .intersect import Intersect
from .java_type import JavaType
from .join import Join
from .joiner import Joiner
from .json_format_attribute import JsonFormatAttribute
from .key import Key
from .key_attribute import KeyAttribute
from .key_range import KeyRange
from .key_range_partition_config import KeyRangePartitionConfig
from .last_run_details import LastRunDetails
from .lookup import Lookup
from .macro_field import MacroField
from .merge_operator import MergeOperator
from .message import Message
from .minus import Minus
from .monthly_frequency_details import MonthlyFrequencyDetails
from .name_list_rule import NameListRule
from .name_pattern_rule import NamePatternRule
from .native_shape_field import NativeShapeField
from .object_metadata import ObjectMetadata
from .object_storage_write_attribute import ObjectStorageWriteAttribute
from .object_storage_write_attributes import ObjectStorageWriteAttributes
from .oci_vault_secret_config import OciVaultSecretConfig
from .operator import Operator
from .oracle_adwc_write_attribute import OracleAdwcWriteAttribute
from .oracle_adwc_write_attributes import OracleAdwcWriteAttributes
from .oracle_atp_write_attribute import OracleAtpWriteAttribute
from .oracle_atp_write_attributes import OracleAtpWriteAttributes
from .oracle_read_attribute import OracleReadAttribute
from .oracle_read_attributes import OracleReadAttributes
from .oracle_write_attribute import OracleWriteAttribute
from .oracle_write_attributes import OracleWriteAttributes
from .output_field import OutputField
from .output_link import OutputLink
from .output_port import OutputPort
from .parameter import Parameter
from .parameter_value import ParameterValue
from .parent_reference import ParentReference
from .parquet_format_attribute import ParquetFormatAttribute
from .partition_config import PartitionConfig
from .patch import Patch
from .patch_change_summary import PatchChangeSummary
from .patch_change_summary_collection import PatchChangeSummaryCollection
from .patch_object_metadata import PatchObjectMetadata
from .patch_summary import PatchSummary
from .patch_summary_collection import PatchSummaryCollection
from .pipeline import Pipeline
from .pipeline_summary import PipelineSummary
from .pipeline_summary_collection import PipelineSummaryCollection
from .pipeline_validation import PipelineValidation
from .pipeline_validation_summary import PipelineValidationSummary
from .pipeline_validation_summary_collection import PipelineValidationSummaryCollection
from .primary_key import PrimaryKey
from .project import Project
from .project_details import ProjectDetails
from .project_summary import ProjectSummary
from .project_summary_collection import ProjectSummaryCollection
from .projection import Projection
from .projection_rule import ProjectionRule
from .proxy_field import ProxyField
from .published_object import PublishedObject
from .published_object_from_data_loader_task import PublishedObjectFromDataLoaderTask
from .published_object_from_integration_task import PublishedObjectFromIntegrationTask
from .published_object_from_pipeline_task import PublishedObjectFromPipelineTask
from .published_object_from_pipeline_task_summary import PublishedObjectFromPipelineTaskSummary
from .published_object_summary import PublishedObjectSummary
from .published_object_summary_collection import PublishedObjectSummaryCollection
from .published_object_summary_from_data_loader_task import PublishedObjectSummaryFromDataLoaderTask
from .published_object_summary_from_integration_task import PublishedObjectSummaryFromIntegrationTask
from .push_down_operation import PushDownOperation
from .query import Query
from .read_operation_config import ReadOperationConfig
from .reference import Reference
from .reference_summary import ReferenceSummary
from .reference_summary_collection import ReferenceSummaryCollection
from .reference_used_by import ReferenceUsedBy
from .registry_metadata import RegistryMetadata
from .rename_rule import RenameRule
from .resource_configuration import ResourceConfiguration
from .root_object import RootObject
from .rule_based_field_map import RuleBasedFieldMap
from .rule_type_config import RuleTypeConfig
from .schedule import Schedule
from .schedule_summary import ScheduleSummary
from .schedule_summary_collection import ScheduleSummaryCollection
from .schema import Schema
from .schema_drift_config import SchemaDriftConfig
from .schema_summary import SchemaSummary
from .schema_summary_collection import SchemaSummaryCollection
from .script import Script
from .secret_config import SecretConfig
from .select import Select
from .sensitive_attribute import SensitiveAttribute
from .shape import Shape
from .shape_field import ShapeField
from .sort import Sort
from .sort_clause import SortClause
from .sort_key import SortKey
from .sort_key_rule import SortKeyRule
from .sort_oper import SortOper
from .source import Source
from .source_application_info import SourceApplicationInfo
from .start_operator import StartOperator
from .structured_type import StructuredType
from .target import Target
from .task import Task
from .task_from_data_loader_task_details import TaskFromDataLoaderTaskDetails
from .task_from_integration_task_details import TaskFromIntegrationTaskDetails
from .task_from_oci_dataflow_task_details import TaskFromOCIDataflowTaskDetails
from .task_from_pipeline_task_details import TaskFromPipelineTaskDetails
from .task_from_rest_task_details import TaskFromRestTaskDetails
from .task_from_sql_task_details import TaskFromSQLTaskDetails
from .task_operator import TaskOperator
from .task_run import TaskRun
from .task_run_details import TaskRunDetails
from .task_run_log_summary import TaskRunLogSummary
from .task_run_summary import TaskRunSummary
from .task_run_summary_collection import TaskRunSummaryCollection
from .task_schedule import TaskSchedule
from .task_schedule_summary import TaskScheduleSummary
from .task_schedule_summary_collection import TaskScheduleSummaryCollection
from .task_summary import TaskSummary
from .task_summary_collection import TaskSummaryCollection
from .task_summary_from_data_loader_task import TaskSummaryFromDataLoaderTask
from .task_summary_from_integration_task import TaskSummaryFromIntegrationTask
from .task_summary_from_oci_dataflow_task import TaskSummaryFromOCIDataflowTask
from .task_summary_from_pipeline_task import TaskSummaryFromPipelineTask
from .task_summary_from_rest_task import TaskSummaryFromRestTask
from .task_summary_from_sql_task import TaskSummaryFromSQLTask
from .task_validation import TaskValidation
from .task_validation_summary import TaskValidationSummary
from .task_validation_summary_collection import TaskValidationSummaryCollection
from .time import Time
from .type_library import TypeLibrary
from .type_list_rule import TypeListRule
from .type_system import TypeSystem
from .typed_name_pattern_rule import TypedNamePatternRule
from .typed_object import TypedObject
from .ui_properties import UIProperties
from .union import Union
from .unique_key import UniqueKey
from .update_application_details import UpdateApplicationDetails
from .update_connection_details import UpdateConnectionDetails
from .update_connection_from_adwc import UpdateConnectionFromAdwc
from .update_connection_from_amazon_s3 import UpdateConnectionFromAmazonS3
from .update_connection_from_atp import UpdateConnectionFromAtp
from .update_connection_from_bicc import UpdateConnectionFromBICC
from .update_connection_from_jdbc import UpdateConnectionFromJdbc
from .update_connection_from_my_sql import UpdateConnectionFromMySQL
from .update_connection_from_object_storage import UpdateConnectionFromObjectStorage
from .update_connection_from_oracle import UpdateConnectionFromOracle
from .update_data_asset_details import UpdateDataAssetDetails
from .update_data_asset_from_adwc import UpdateDataAssetFromAdwc
from .update_data_asset_from_amazon_s3 import UpdateDataAssetFromAmazonS3
from .update_data_asset_from_atp import UpdateDataAssetFromAtp
from .update_data_asset_from_fusion_app import UpdateDataAssetFromFusionApp
from .update_data_asset_from_jdbc import UpdateDataAssetFromJdbc
from .update_data_asset_from_my_sql import UpdateDataAssetFromMySQL
from .update_data_asset_from_object_storage import UpdateDataAssetFromObjectStorage
from .update_data_asset_from_oracle import UpdateDataAssetFromOracle
from .update_data_flow_details import UpdateDataFlowDetails
from .update_external_publication_details import UpdateExternalPublicationDetails
from .update_folder_details import UpdateFolderDetails
from .update_pipeline_details import UpdatePipelineDetails
from .update_project_details import UpdateProjectDetails
from .update_reference_details import UpdateReferenceDetails
from .update_schedule_details import UpdateScheduleDetails
from .update_task_details import UpdateTaskDetails
from .update_task_from_data_loader_task import UpdateTaskFromDataLoaderTask
from .update_task_from_integration_task import UpdateTaskFromIntegrationTask
from .update_task_from_oci_dataflow_task import UpdateTaskFromOCIDataflowTask
from .update_task_from_pipeline_task import UpdateTaskFromPipelineTask
from .update_task_from_rest_task import UpdateTaskFromRestTask
from .update_task_from_sql_task import UpdateTaskFromSQLTask
from .update_task_run_details import UpdateTaskRunDetails
from .update_task_schedule_details import UpdateTaskScheduleDetails
from .update_workspace_details import UpdateWorkspaceDetails
from .validation_message import ValidationMessage
from .variable import Variable
from .work_request import WorkRequest
from .work_request_error import WorkRequestError
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary
from .workspace import Workspace
from .workspace_summary import WorkspaceSummary
from .write_operation_config import WriteOperationConfig

# Maps type names to classes for data_integration services.
data_integration_type_mapping = {
    "AbstractDataOperationConfig": AbstractDataOperationConfig,
    "AbstractField": AbstractField,
    "AbstractFormatAttribute": AbstractFormatAttribute,
    "AbstractFrequencyDetails": AbstractFrequencyDetails,
    "AbstractReadAttribute": AbstractReadAttribute,
    "AbstractWriteAttribute": AbstractWriteAttribute,
    "Aggregator": Aggregator,
    "AggregatorSummary": AggregatorSummary,
    "Application": Application,
    "ApplicationDetails": ApplicationDetails,
    "ApplicationSummary": ApplicationSummary,
    "ApplicationSummaryCollection": ApplicationSummaryCollection,
    "AuthDetails": AuthDetails,
    "AvroFormatAttribute": AvroFormatAttribute,
    "BaseType": BaseType,
    "BiccReadAttributes": BiccReadAttributes,
    "ChangeCompartmentDetails": ChangeCompartmentDetails,
    "ChildReference": ChildReference,
    "ChildReferenceDetail": ChildReferenceDetail,
    "CompositeFieldMap": CompositeFieldMap,
    "CompositeType": CompositeType,
    "Compression": Compression,
    "ConditionalInputLink": ConditionalInputLink,
    "ConfigDefinition": ConfigDefinition,
    "ConfigParameterDefinition": ConfigParameterDefinition,
    "ConfigParameterValue": ConfigParameterValue,
    "ConfigProvider": ConfigProvider,
    "ConfigValues": ConfigValues,
    "ConfigurationDetails": ConfigurationDetails,
    "ConfiguredType": ConfiguredType,
    "Connection": Connection,
    "ConnectionDetails": ConnectionDetails,
    "ConnectionFromAdwc": ConnectionFromAdwc,
    "ConnectionFromAdwcDetails": ConnectionFromAdwcDetails,
    "ConnectionFromAmazonS3": ConnectionFromAmazonS3,
    "ConnectionFromAmazonS3Details": ConnectionFromAmazonS3Details,
    "ConnectionFromAtp": ConnectionFromAtp,
    "ConnectionFromAtpDetails": ConnectionFromAtpDetails,
    "ConnectionFromBICC": ConnectionFromBICC,
    "ConnectionFromBICCDetails": ConnectionFromBICCDetails,
    "ConnectionFromJdbc": ConnectionFromJdbc,
    "ConnectionFromJdbcDetails": ConnectionFromJdbcDetails,
    "ConnectionFromMySQL": ConnectionFromMySQL,
    "ConnectionFromMySQLDetails": ConnectionFromMySQLDetails,
    "ConnectionFromObjectStorage": ConnectionFromObjectStorage,
    "ConnectionFromObjectStorageDetails": ConnectionFromObjectStorageDetails,
    "ConnectionFromOracle": ConnectionFromOracle,
    "ConnectionFromOracleDetails": ConnectionFromOracleDetails,
    "ConnectionProperty": ConnectionProperty,
    "ConnectionSummary": ConnectionSummary,
    "ConnectionSummaryCollection": ConnectionSummaryCollection,
    "ConnectionSummaryFromAdwc": ConnectionSummaryFromAdwc,
    "ConnectionSummaryFromAmazonS3": ConnectionSummaryFromAmazonS3,
    "ConnectionSummaryFromAtp": ConnectionSummaryFromAtp,
    "ConnectionSummaryFromBICC": ConnectionSummaryFromBICC,
    "ConnectionSummaryFromJdbc": ConnectionSummaryFromJdbc,
    "ConnectionSummaryFromMySQL": ConnectionSummaryFromMySQL,
    "ConnectionSummaryFromObjectStorage": ConnectionSummaryFromObjectStorage,
    "ConnectionSummaryFromOracle": ConnectionSummaryFromOracle,
    "ConnectionValidation": ConnectionValidation,
    "ConnectionValidationSummary": ConnectionValidationSummary,
    "ConnectionValidationSummaryCollection": ConnectionValidationSummaryCollection,
    "ConnectorAttribute": ConnectorAttribute,
    "CountStatistic": CountStatistic,
    "CountStatisticSummary": CountStatisticSummary,
    "CreateApplicationDetails": CreateApplicationDetails,
    "CreateConfigProvider": CreateConfigProvider,
    "CreateConnectionDetails": CreateConnectionDetails,
    "CreateConnectionFromAdwc": CreateConnectionFromAdwc,
    "CreateConnectionFromAmazonS3": CreateConnectionFromAmazonS3,
    "CreateConnectionFromAtp": CreateConnectionFromAtp,
    "CreateConnectionFromBICC": CreateConnectionFromBICC,
    "CreateConnectionFromJdbc": CreateConnectionFromJdbc,
    "CreateConnectionFromMySQL": CreateConnectionFromMySQL,
    "CreateConnectionFromObjectStorage": CreateConnectionFromObjectStorage,
    "CreateConnectionFromOracle": CreateConnectionFromOracle,
    "CreateConnectionValidationDetails": CreateConnectionValidationDetails,
    "CreateDataAssetDetails": CreateDataAssetDetails,
    "CreateDataAssetFromAdwc": CreateDataAssetFromAdwc,
    "CreateDataAssetFromAmazonS3": CreateDataAssetFromAmazonS3,
    "CreateDataAssetFromAtp": CreateDataAssetFromAtp,
    "CreateDataAssetFromFusionApp": CreateDataAssetFromFusionApp,
    "CreateDataAssetFromJdbc": CreateDataAssetFromJdbc,
    "CreateDataAssetFromMySQL": CreateDataAssetFromMySQL,
    "CreateDataAssetFromObjectStorage": CreateDataAssetFromObjectStorage,
    "CreateDataAssetFromOracle": CreateDataAssetFromOracle,
    "CreateDataFlowDetails": CreateDataFlowDetails,
    "CreateDataFlowValidationDetails": CreateDataFlowValidationDetails,
    "CreateEntityShapeDetails": CreateEntityShapeDetails,
    "CreateEntityShapeFromFile": CreateEntityShapeFromFile,
    "CreateExternalPublicationDetails": CreateExternalPublicationDetails,
    "CreateExternalPublicationValidationDetails": CreateExternalPublicationValidationDetails,
    "CreateFolderDetails": CreateFolderDetails,
    "CreatePatchDetails": CreatePatchDetails,
    "CreatePipelineDetails": CreatePipelineDetails,
    "CreatePipelineValidationDetails": CreatePipelineValidationDetails,
    "CreateProjectDetails": CreateProjectDetails,
    "CreateScheduleDetails": CreateScheduleDetails,
    "CreateSourceApplicationInfo": CreateSourceApplicationInfo,
    "CreateTaskDetails": CreateTaskDetails,
    "CreateTaskFromDataLoaderTask": CreateTaskFromDataLoaderTask,
    "CreateTaskFromIntegrationTask": CreateTaskFromIntegrationTask,
    "CreateTaskFromOCIDataflowTask": CreateTaskFromOCIDataflowTask,
    "CreateTaskFromPipelineTask": CreateTaskFromPipelineTask,
    "CreateTaskFromRestTask": CreateTaskFromRestTask,
    "CreateTaskFromSQLTask": CreateTaskFromSQLTask,
    "CreateTaskRunDetails": CreateTaskRunDetails,
    "CreateTaskScheduleDetails": CreateTaskScheduleDetails,
    "CreateTaskValidationDetails": CreateTaskValidationDetails,
    "CreateTaskValidationFromDataLoaderTask": CreateTaskValidationFromDataLoaderTask,
    "CreateTaskValidationFromIntegrationTask": CreateTaskValidationFromIntegrationTask,
    "CreateTaskValidationFromPipelineTask": CreateTaskValidationFromPipelineTask,
    "CreateWorkspaceDetails": CreateWorkspaceDetails,
    "CsvFormatAttribute": CsvFormatAttribute,
    "DailyFrequencyDetails": DailyFrequencyDetails,
    "DataAsset": DataAsset,
    "DataAssetFromAdwcDetails": DataAssetFromAdwcDetails,
    "DataAssetFromAmazonS3": DataAssetFromAmazonS3,
    "DataAssetFromAtpDetails": DataAssetFromAtpDetails,
    "DataAssetFromFusionApp": DataAssetFromFusionApp,
    "DataAssetFromJdbc": DataAssetFromJdbc,
    "DataAssetFromMySQL": DataAssetFromMySQL,
    "DataAssetFromObjectStorageDetails": DataAssetFromObjectStorageDetails,
    "DataAssetFromOracleDetails": DataAssetFromOracleDetails,
    "DataAssetSummary": DataAssetSummary,
    "DataAssetSummaryCollection": DataAssetSummaryCollection,
    "DataAssetSummaryFromAdwc": DataAssetSummaryFromAdwc,
    "DataAssetSummaryFromAmazonS3": DataAssetSummaryFromAmazonS3,
    "DataAssetSummaryFromAtp": DataAssetSummaryFromAtp,
    "DataAssetSummaryFromFusionApp": DataAssetSummaryFromFusionApp,
    "DataAssetSummaryFromJdbc": DataAssetSummaryFromJdbc,
    "DataAssetSummaryFromMySQL": DataAssetSummaryFromMySQL,
    "DataAssetSummaryFromObjectStorage": DataAssetSummaryFromObjectStorage,
    "DataAssetSummaryFromOracle": DataAssetSummaryFromOracle,
    "DataEntity": DataEntity,
    "DataEntityDetails": DataEntityDetails,
    "DataEntityFromDataStore": DataEntityFromDataStore,
    "DataEntityFromDataStoreEntityDetails": DataEntityFromDataStoreEntityDetails,
    "DataEntityFromFile": DataEntityFromFile,
    "DataEntityFromFileEntityDetails": DataEntityFromFileEntityDetails,
    "DataEntityFromTable": DataEntityFromTable,
    "DataEntityFromTableEntityDetails": DataEntityFromTableEntityDetails,
    "DataEntityFromView": DataEntityFromView,
    "DataEntityFromViewEntityDetails": DataEntityFromViewEntityDetails,
    "DataEntitySummary": DataEntitySummary,
    "DataEntitySummaryCollection": DataEntitySummaryCollection,
    "DataEntitySummaryFromDataStore": DataEntitySummaryFromDataStore,
    "DataEntitySummaryFromFile": DataEntitySummaryFromFile,
    "DataEntitySummaryFromTable": DataEntitySummaryFromTable,
    "DataEntitySummaryFromView": DataEntitySummaryFromView,
    "DataFlow": DataFlow,
    "DataFlowDetails": DataFlowDetails,
    "DataFlowSummary": DataFlowSummary,
    "DataFlowSummaryCollection": DataFlowSummaryCollection,
    "DataFlowValidation": DataFlowValidation,
    "DataFlowValidationSummary": DataFlowValidationSummary,
    "DataFlowValidationSummaryCollection": DataFlowValidationSummaryCollection,
    "DataFormat": DataFormat,
    "DataType": DataType,
    "DataflowApplication": DataflowApplication,
    "DependentObject": DependentObject,
    "DependentObjectSummary": DependentObjectSummary,
    "DependentObjectSummaryCollection": DependentObjectSummaryCollection,
    "DerivedField": DerivedField,
    "DerivedType": DerivedType,
    "DirectFieldMap": DirectFieldMap,
    "DirectNamedFieldMap": DirectNamedFieldMap,
    "Distinct": Distinct,
    "DynamicInputField": DynamicInputField,
    "DynamicProxyField": DynamicProxyField,
    "DynamicType": DynamicType,
    "DynamicTypeHandler": DynamicTypeHandler,
    "EndOperator": EndOperator,
    "EnrichedEntity": EnrichedEntity,
    "EntityShape": EntityShape,
    "EntityShapeFromFile": EntityShapeFromFile,
    "ErrorDetails": ErrorDetails,
    "Expression": Expression,
    "ExpressionOperator": ExpressionOperator,
    "ExternalPublication": ExternalPublication,
    "ExternalPublicationSummary": ExternalPublicationSummary,
    "ExternalPublicationSummaryCollection": ExternalPublicationSummaryCollection,
    "ExternalPublicationValidation": ExternalPublicationValidation,
    "ExternalPublicationValidationSummary": ExternalPublicationValidationSummary,
    "ExternalPublicationValidationSummaryCollection": ExternalPublicationValidationSummaryCollection,
    "ExternalStorage": ExternalStorage,
    "FieldMap": FieldMap,
    "Filter": Filter,
    "FilterPush": FilterPush,
    "FlowNode": FlowNode,
    "FlowPort": FlowPort,
    "FlowPortLink": FlowPortLink,
    "Folder": Folder,
    "FolderDetails": FolderDetails,
    "FolderSummary": FolderSummary,
    "FolderSummaryCollection": FolderSummaryCollection,
    "ForeignKey": ForeignKey,
    "HourlyFrequencyDetails": HourlyFrequencyDetails,
    "InputField": InputField,
    "InputLink": InputLink,
    "InputPort": InputPort,
    "Intersect": Intersect,
    "JavaType": JavaType,
    "Join": Join,
    "Joiner": Joiner,
    "JsonFormatAttribute": JsonFormatAttribute,
    "Key": Key,
    "KeyAttribute": KeyAttribute,
    "KeyRange": KeyRange,
    "KeyRangePartitionConfig": KeyRangePartitionConfig,
    "LastRunDetails": LastRunDetails,
    "Lookup": Lookup,
    "MacroField": MacroField,
    "MergeOperator": MergeOperator,
    "Message": Message,
    "Minus": Minus,
    "MonthlyFrequencyDetails": MonthlyFrequencyDetails,
    "NameListRule": NameListRule,
    "NamePatternRule": NamePatternRule,
    "NativeShapeField": NativeShapeField,
    "ObjectMetadata": ObjectMetadata,
    "ObjectStorageWriteAttribute": ObjectStorageWriteAttribute,
    "ObjectStorageWriteAttributes": ObjectStorageWriteAttributes,
    "OciVaultSecretConfig": OciVaultSecretConfig,
    "Operator": Operator,
    "OracleAdwcWriteAttribute": OracleAdwcWriteAttribute,
    "OracleAdwcWriteAttributes": OracleAdwcWriteAttributes,
    "OracleAtpWriteAttribute": OracleAtpWriteAttribute,
    "OracleAtpWriteAttributes": OracleAtpWriteAttributes,
    "OracleReadAttribute": OracleReadAttribute,
    "OracleReadAttributes": OracleReadAttributes,
    "OracleWriteAttribute": OracleWriteAttribute,
    "OracleWriteAttributes": OracleWriteAttributes,
    "OutputField": OutputField,
    "OutputLink": OutputLink,
    "OutputPort": OutputPort,
    "Parameter": Parameter,
    "ParameterValue": ParameterValue,
    "ParentReference": ParentReference,
    "ParquetFormatAttribute": ParquetFormatAttribute,
    "PartitionConfig": PartitionConfig,
    "Patch": Patch,
    "PatchChangeSummary": PatchChangeSummary,
    "PatchChangeSummaryCollection": PatchChangeSummaryCollection,
    "PatchObjectMetadata": PatchObjectMetadata,
    "PatchSummary": PatchSummary,
    "PatchSummaryCollection": PatchSummaryCollection,
    "Pipeline": Pipeline,
    "PipelineSummary": PipelineSummary,
    "PipelineSummaryCollection": PipelineSummaryCollection,
    "PipelineValidation": PipelineValidation,
    "PipelineValidationSummary": PipelineValidationSummary,
    "PipelineValidationSummaryCollection": PipelineValidationSummaryCollection,
    "PrimaryKey": PrimaryKey,
    "Project": Project,
    "ProjectDetails": ProjectDetails,
    "ProjectSummary": ProjectSummary,
    "ProjectSummaryCollection": ProjectSummaryCollection,
    "Projection": Projection,
    "ProjectionRule": ProjectionRule,
    "ProxyField": ProxyField,
    "PublishedObject": PublishedObject,
    "PublishedObjectFromDataLoaderTask": PublishedObjectFromDataLoaderTask,
    "PublishedObjectFromIntegrationTask": PublishedObjectFromIntegrationTask,
    "PublishedObjectFromPipelineTask": PublishedObjectFromPipelineTask,
    "PublishedObjectFromPipelineTaskSummary": PublishedObjectFromPipelineTaskSummary,
    "PublishedObjectSummary": PublishedObjectSummary,
    "PublishedObjectSummaryCollection": PublishedObjectSummaryCollection,
    "PublishedObjectSummaryFromDataLoaderTask": PublishedObjectSummaryFromDataLoaderTask,
    "PublishedObjectSummaryFromIntegrationTask": PublishedObjectSummaryFromIntegrationTask,
    "PushDownOperation": PushDownOperation,
    "Query": Query,
    "ReadOperationConfig": ReadOperationConfig,
    "Reference": Reference,
    "ReferenceSummary": ReferenceSummary,
    "ReferenceSummaryCollection": ReferenceSummaryCollection,
    "ReferenceUsedBy": ReferenceUsedBy,
    "RegistryMetadata": RegistryMetadata,
    "RenameRule": RenameRule,
    "ResourceConfiguration": ResourceConfiguration,
    "RootObject": RootObject,
    "RuleBasedFieldMap": RuleBasedFieldMap,
    "RuleTypeConfig": RuleTypeConfig,
    "Schedule": Schedule,
    "ScheduleSummary": ScheduleSummary,
    "ScheduleSummaryCollection": ScheduleSummaryCollection,
    "Schema": Schema,
    "SchemaDriftConfig": SchemaDriftConfig,
    "SchemaSummary": SchemaSummary,
    "SchemaSummaryCollection": SchemaSummaryCollection,
    "Script": Script,
    "SecretConfig": SecretConfig,
    "Select": Select,
    "SensitiveAttribute": SensitiveAttribute,
    "Shape": Shape,
    "ShapeField": ShapeField,
    "Sort": Sort,
    "SortClause": SortClause,
    "SortKey": SortKey,
    "SortKeyRule": SortKeyRule,
    "SortOper": SortOper,
    "Source": Source,
    "SourceApplicationInfo": SourceApplicationInfo,
    "StartOperator": StartOperator,
    "StructuredType": StructuredType,
    "Target": Target,
    "Task": Task,
    "TaskFromDataLoaderTaskDetails": TaskFromDataLoaderTaskDetails,
    "TaskFromIntegrationTaskDetails": TaskFromIntegrationTaskDetails,
    "TaskFromOCIDataflowTaskDetails": TaskFromOCIDataflowTaskDetails,
    "TaskFromPipelineTaskDetails": TaskFromPipelineTaskDetails,
    "TaskFromRestTaskDetails": TaskFromRestTaskDetails,
    "TaskFromSQLTaskDetails": TaskFromSQLTaskDetails,
    "TaskOperator": TaskOperator,
    "TaskRun": TaskRun,
    "TaskRunDetails": TaskRunDetails,
    "TaskRunLogSummary": TaskRunLogSummary,
    "TaskRunSummary": TaskRunSummary,
    "TaskRunSummaryCollection": TaskRunSummaryCollection,
    "TaskSchedule": TaskSchedule,
    "TaskScheduleSummary": TaskScheduleSummary,
    "TaskScheduleSummaryCollection": TaskScheduleSummaryCollection,
    "TaskSummary": TaskSummary,
    "TaskSummaryCollection": TaskSummaryCollection,
    "TaskSummaryFromDataLoaderTask": TaskSummaryFromDataLoaderTask,
    "TaskSummaryFromIntegrationTask": TaskSummaryFromIntegrationTask,
    "TaskSummaryFromOCIDataflowTask": TaskSummaryFromOCIDataflowTask,
    "TaskSummaryFromPipelineTask": TaskSummaryFromPipelineTask,
    "TaskSummaryFromRestTask": TaskSummaryFromRestTask,
    "TaskSummaryFromSQLTask": TaskSummaryFromSQLTask,
    "TaskValidation": TaskValidation,
    "TaskValidationSummary": TaskValidationSummary,
    "TaskValidationSummaryCollection": TaskValidationSummaryCollection,
    "Time": Time,
    "TypeLibrary": TypeLibrary,
    "TypeListRule": TypeListRule,
    "TypeSystem": TypeSystem,
    "TypedNamePatternRule": TypedNamePatternRule,
    "TypedObject": TypedObject,
    "UIProperties": UIProperties,
    "Union": Union,
    "UniqueKey": UniqueKey,
    "UpdateApplicationDetails": UpdateApplicationDetails,
    "UpdateConnectionDetails": UpdateConnectionDetails,
    "UpdateConnectionFromAdwc": UpdateConnectionFromAdwc,
    "UpdateConnectionFromAmazonS3": UpdateConnectionFromAmazonS3,
    "UpdateConnectionFromAtp": UpdateConnectionFromAtp,
    "UpdateConnectionFromBICC": UpdateConnectionFromBICC,
    "UpdateConnectionFromJdbc": UpdateConnectionFromJdbc,
    "UpdateConnectionFromMySQL": UpdateConnectionFromMySQL,
    "UpdateConnectionFromObjectStorage": UpdateConnectionFromObjectStorage,
    "UpdateConnectionFromOracle": UpdateConnectionFromOracle,
    "UpdateDataAssetDetails": UpdateDataAssetDetails,
    "UpdateDataAssetFromAdwc": UpdateDataAssetFromAdwc,
    "UpdateDataAssetFromAmazonS3": UpdateDataAssetFromAmazonS3,
    "UpdateDataAssetFromAtp": UpdateDataAssetFromAtp,
    "UpdateDataAssetFromFusionApp": UpdateDataAssetFromFusionApp,
    "UpdateDataAssetFromJdbc": UpdateDataAssetFromJdbc,
    "UpdateDataAssetFromMySQL": UpdateDataAssetFromMySQL,
    "UpdateDataAssetFromObjectStorage": UpdateDataAssetFromObjectStorage,
    "UpdateDataAssetFromOracle": UpdateDataAssetFromOracle,
    "UpdateDataFlowDetails": UpdateDataFlowDetails,
    "UpdateExternalPublicationDetails": UpdateExternalPublicationDetails,
    "UpdateFolderDetails": UpdateFolderDetails,
    "UpdatePipelineDetails": UpdatePipelineDetails,
    "UpdateProjectDetails": UpdateProjectDetails,
    "UpdateReferenceDetails": UpdateReferenceDetails,
    "UpdateScheduleDetails": UpdateScheduleDetails,
    "UpdateTaskDetails": UpdateTaskDetails,
    "UpdateTaskFromDataLoaderTask": UpdateTaskFromDataLoaderTask,
    "UpdateTaskFromIntegrationTask": UpdateTaskFromIntegrationTask,
    "UpdateTaskFromOCIDataflowTask": UpdateTaskFromOCIDataflowTask,
    "UpdateTaskFromPipelineTask": UpdateTaskFromPipelineTask,
    "UpdateTaskFromRestTask": UpdateTaskFromRestTask,
    "UpdateTaskFromSQLTask": UpdateTaskFromSQLTask,
    "UpdateTaskRunDetails": UpdateTaskRunDetails,
    "UpdateTaskScheduleDetails": UpdateTaskScheduleDetails,
    "UpdateWorkspaceDetails": UpdateWorkspaceDetails,
    "ValidationMessage": ValidationMessage,
    "Variable": Variable,
    "WorkRequest": WorkRequest,
    "WorkRequestError": WorkRequestError,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary,
    "Workspace": Workspace,
    "WorkspaceSummary": WorkspaceSummary,
    "WriteOperationConfig": WriteOperationConfig
}



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .data_asset import DataAsset
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DataAssetFromAmazonS3(DataAsset):
    """
    Details for the MYSQL data asset type.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DataAssetFromAmazonS3 object with values from keyword arguments. The default value of the :py:attr:`~oci.data_integration.models.DataAssetFromAmazonS3.model_type` attribute
        of this class is ``AMAZON_S3_DATA_ASSET`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this DataAssetFromAmazonS3.
            Allowed values for this property are: "ORACLE_DATA_ASSET", "ORACLE_OBJECT_STORAGE_DATA_ASSET", "ORACLE_ATP_DATA_ASSET", "ORACLE_ADWC_DATA_ASSET", "MYSQL_DATA_ASSET", "GENERIC_JDBC_DATA_ASSET", "FUSION_APP_DATA_ASSET", "AMAZON_S3_DATA_ASSET"
        :type model_type: str

        :param key:
            The value to assign to the key property of this DataAssetFromAmazonS3.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this DataAssetFromAmazonS3.
        :type model_version: str

        :param name:
            The value to assign to the name property of this DataAssetFromAmazonS3.
        :type name: str

        :param description:
            The value to assign to the description property of this DataAssetFromAmazonS3.
        :type description: str

        :param object_status:
            The value to assign to the object_status property of this DataAssetFromAmazonS3.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this DataAssetFromAmazonS3.
        :type identifier: str

        :param external_key:
            The value to assign to the external_key property of this DataAssetFromAmazonS3.
        :type external_key: str

        :param asset_properties:
            The value to assign to the asset_properties property of this DataAssetFromAmazonS3.
        :type asset_properties: dict(str, str)

        :param native_type_system:
            The value to assign to the native_type_system property of this DataAssetFromAmazonS3.
        :type native_type_system: oci.data_integration.models.TypeSystem

        :param object_version:
            The value to assign to the object_version property of this DataAssetFromAmazonS3.
        :type object_version: int

        :param parent_ref:
            The value to assign to the parent_ref property of this DataAssetFromAmazonS3.
        :type parent_ref: oci.data_integration.models.ParentReference

        :param metadata:
            The value to assign to the metadata property of this DataAssetFromAmazonS3.
        :type metadata: oci.data_integration.models.ObjectMetadata

        :param key_map:
            The value to assign to the key_map property of this DataAssetFromAmazonS3.
        :type key_map: dict(str, str)

        :param region:
            The value to assign to the region property of this DataAssetFromAmazonS3.
        :type region: str

        :param default_connection:
            The value to assign to the default_connection property of this DataAssetFromAmazonS3.
        :type default_connection: oci.data_integration.models.ConnectionSummaryFromAmazonS3

        """
        self.swagger_types = {
            'model_type': 'str',
            'key': 'str',
            'model_version': 'str',
            'name': 'str',
            'description': 'str',
            'object_status': 'int',
            'identifier': 'str',
            'external_key': 'str',
            'asset_properties': 'dict(str, str)',
            'native_type_system': 'TypeSystem',
            'object_version': 'int',
            'parent_ref': 'ParentReference',
            'metadata': 'ObjectMetadata',
            'key_map': 'dict(str, str)',
            'region': 'str',
            'default_connection': 'ConnectionSummaryFromAmazonS3'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'key': 'key',
            'model_version': 'modelVersion',
            'name': 'name',
            'description': 'description',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'external_key': 'externalKey',
            'asset_properties': 'assetProperties',
            'native_type_system': 'nativeTypeSystem',
            'object_version': 'objectVersion',
            'parent_ref': 'parentRef',
            'metadata': 'metadata',
            'key_map': 'keyMap',
            'region': 'region',
            'default_connection': 'defaultConnection'
        }

        self._model_type = None
        self._key = None
        self._model_version = None
        self._name = None
        self._description = None
        self._object_status = None
        self._identifier = None
        self._external_key = None
        self._asset_properties = None
        self._native_type_system = None
        self._object_version = None
        self._parent_ref = None
        self._metadata = None
        self._key_map = None
        self._region = None
        self._default_connection = None
        self._model_type = 'AMAZON_S3_DATA_ASSET'

    @property
    def region(self):
        """
        Gets the region of this DataAssetFromAmazonS3.
        The region for Amazon s3


        :return: The region of this DataAssetFromAmazonS3.
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region):
        """
        Sets the region of this DataAssetFromAmazonS3.
        The region for Amazon s3


        :param region: The region of this DataAssetFromAmazonS3.
        :type: str
        """
        self._region = region

    @property
    def default_connection(self):
        """
        Gets the default_connection of this DataAssetFromAmazonS3.

        :return: The default_connection of this DataAssetFromAmazonS3.
        :rtype: oci.data_integration.models.ConnectionSummaryFromAmazonS3
        """
        return self._default_connection

    @default_connection.setter
    def default_connection(self, default_connection):
        """
        Sets the default_connection of this DataAssetFromAmazonS3.

        :param default_connection: The default_connection of this DataAssetFromAmazonS3.
        :type: oci.data_integration.models.ConnectionSummaryFromAmazonS3
        """
        self._default_connection = default_connection

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ClusterCreateOptions(object):
    """
    The properties that define extra options for a cluster.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ClusterCreateOptions object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param service_lb_subnet_ids:
            The value to assign to the service_lb_subnet_ids property of this ClusterCreateOptions.
        :type service_lb_subnet_ids: list[str]

        :param kubernetes_network_config:
            The value to assign to the kubernetes_network_config property of this ClusterCreateOptions.
        :type kubernetes_network_config: oci.container_engine.models.KubernetesNetworkConfig

        :param add_ons:
            The value to assign to the add_ons property of this ClusterCreateOptions.
        :type add_ons: oci.container_engine.models.AddOnOptions

        :param admission_controller_options:
            The value to assign to the admission_controller_options property of this ClusterCreateOptions.
        :type admission_controller_options: oci.container_engine.models.AdmissionControllerOptions

        """
        self.swagger_types = {
            'service_lb_subnet_ids': 'list[str]',
            'kubernetes_network_config': 'KubernetesNetworkConfig',
            'add_ons': 'AddOnOptions',
            'admission_controller_options': 'AdmissionControllerOptions'
        }

        self.attribute_map = {
            'service_lb_subnet_ids': 'serviceLbSubnetIds',
            'kubernetes_network_config': 'kubernetesNetworkConfig',
            'add_ons': 'addOns',
            'admission_controller_options': 'admissionControllerOptions'
        }

        self._service_lb_subnet_ids = None
        self._kubernetes_network_config = None
        self._add_ons = None
        self._admission_controller_options = None

    @property
    def service_lb_subnet_ids(self):
        """
        Gets the service_lb_subnet_ids of this ClusterCreateOptions.
        The OCIDs of the subnets used for Kubernetes services load balancers.


        :return: The service_lb_subnet_ids of this ClusterCreateOptions.
        :rtype: list[str]
        """
        return self._service_lb_subnet_ids

    @service_lb_subnet_ids.setter
    def service_lb_subnet_ids(self, service_lb_subnet_ids):
        """
        Sets the service_lb_subnet_ids of this ClusterCreateOptions.
        The OCIDs of the subnets used for Kubernetes services load balancers.


        :param service_lb_subnet_ids: The service_lb_subnet_ids of this ClusterCreateOptions.
        :type: list[str]
        """
        self._service_lb_subnet_ids = service_lb_subnet_ids

    @property
    def kubernetes_network_config(self):
        """
        Gets the kubernetes_network_config of this ClusterCreateOptions.
        Network configuration for Kubernetes.


        :return: The kubernetes_network_config of this ClusterCreateOptions.
        :rtype: oci.container_engine.models.KubernetesNetworkConfig
        """
        return self._kubernetes_network_config

    @kubernetes_network_config.setter
    def kubernetes_network_config(self, kubernetes_network_config):
        """
        Sets the kubernetes_network_config of this ClusterCreateOptions.
        Network configuration for Kubernetes.


        :param kubernetes_network_config: The kubernetes_network_config of this ClusterCreateOptions.
        :type: oci.container_engine.models.KubernetesNetworkConfig
        """
        self._kubernetes_network_config = kubernetes_network_config

    @property
    def add_ons(self):
        """
        Gets the add_ons of this ClusterCreateOptions.
        Configurable cluster add-ons


        :return: The add_ons of this ClusterCreateOptions.
        :rtype: oci.container_engine.models.AddOnOptions
        """
        return self._add_ons

    @add_ons.setter
    def add_ons(self, add_ons):
        """
        Sets the add_ons of this ClusterCreateOptions.
        Configurable cluster add-ons


        :param add_ons: The add_ons of this ClusterCreateOptions.
        :type: oci.container_engine.models.AddOnOptions
        """
        self._add_ons = add_ons

    @property
    def admission_controller_options(self):
        """
        Gets the admission_controller_options of this ClusterCreateOptions.
        Configurable cluster admission controllers


        :return: The admission_controller_options of this ClusterCreateOptions.
        :rtype: oci.container_engine.models.AdmissionControllerOptions
        """
        return self._admission_controller_options

    @admission_controller_options.setter
    def admission_controller_options(self, admission_controller_options):
        """
        Sets the admission_controller_options of this ClusterCreateOptions.
        Configurable cluster admission controllers


        :param admission_controller_options: The admission_controller_options of this ClusterCreateOptions.
        :type: oci.container_engine.models.AdmissionControllerOptions
        """
        self._admission_controller_options = admission_controller_options

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateVlanDetails(object):
    """
    UpdateVlanDetails model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateVlanDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateVlanDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this UpdateVlanDetails.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateVlanDetails.
        :type freeform_tags: dict(str, str)

        :param nsg_ids:
            The value to assign to the nsg_ids property of this UpdateVlanDetails.
        :type nsg_ids: list[str]

        :param route_table_id:
            The value to assign to the route_table_id property of this UpdateVlanDetails.
        :type route_table_id: str

        :param cidr_block:
            The value to assign to the cidr_block property of this UpdateVlanDetails.
        :type cidr_block: str

        """
        self.swagger_types = {
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'nsg_ids': 'list[str]',
            'route_table_id': 'str',
            'cidr_block': 'str'
        }

        self.attribute_map = {
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'nsg_ids': 'nsgIds',
            'route_table_id': 'routeTableId',
            'cidr_block': 'cidrBlock'
        }

        self._defined_tags = None
        self._display_name = None
        self._freeform_tags = None
        self._nsg_ids = None
        self._route_table_id = None
        self._cidr_block = None

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this UpdateVlanDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this UpdateVlanDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this UpdateVlanDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this UpdateVlanDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        Gets the display_name of this UpdateVlanDetails.
        A descriptive name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this UpdateVlanDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this UpdateVlanDetails.
        A descriptive name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this UpdateVlanDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this UpdateVlanDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this UpdateVlanDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this UpdateVlanDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this UpdateVlanDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def nsg_ids(self):
        """
        Gets the nsg_ids of this UpdateVlanDetails.
        A list of the OCIDs of the network security groups (NSGs) to use with
        this VLAN. All VNICs in the VLAN will belong to these NSGs. For more
        information about NSGs, see
        :class:`NetworkSecurityGroup`.


        :return: The nsg_ids of this UpdateVlanDetails.
        :rtype: list[str]
        """
        return self._nsg_ids

    @nsg_ids.setter
    def nsg_ids(self, nsg_ids):
        """
        Sets the nsg_ids of this UpdateVlanDetails.
        A list of the OCIDs of the network security groups (NSGs) to use with
        this VLAN. All VNICs in the VLAN will belong to these NSGs. For more
        information about NSGs, see
        :class:`NetworkSecurityGroup`.


        :param nsg_ids: The nsg_ids of this UpdateVlanDetails.
        :type: list[str]
        """
        self._nsg_ids = nsg_ids

    @property
    def route_table_id(self):
        """
        Gets the route_table_id of this UpdateVlanDetails.
        The OCID of the route table the VLAN will use.


        :return: The route_table_id of this UpdateVlanDetails.
        :rtype: str
        """
        return self._route_table_id

    @route_table_id.setter
    def route_table_id(self, route_table_id):
        """
        Sets the route_table_id of this UpdateVlanDetails.
        The OCID of the route table the VLAN will use.


        :param route_table_id: The route_table_id of this UpdateVlanDetails.
        :type: str
        """
        self._route_table_id = route_table_id

    @property
    def cidr_block(self):
        """
        Gets the cidr_block of this UpdateVlanDetails.
        The CIDR block of the VLAN. The new CIDR block must meet the following criteria:

        - Must be valid.
        - The CIDR block's IP range must be completely within one of the VCN's CIDR block ranges.
        - The old and new CIDR block ranges must use the same network address. Example: `10.0.0.0/25` and `10.0.0.0/24`.
        - Must contain all IP addresses in use in the old CIDR range.
        - The new CIDR range's broadcast address (last IP address of CIDR range) must not be an IP address in use in the old CIDR range.

        **Note:** If you are changing the CIDR block, you cannot create VNICs or private IPs for this resource while the update is in progress.


        :return: The cidr_block of this UpdateVlanDetails.
        :rtype: str
        """
        return self._cidr_block

    @cidr_block.setter
    def cidr_block(self, cidr_block):
        """
        Sets the cidr_block of this UpdateVlanDetails.
        The CIDR block of the VLAN. The new CIDR block must meet the following criteria:

        - Must be valid.
        - The CIDR block's IP range must be completely within one of the VCN's CIDR block ranges.
        - The old and new CIDR block ranges must use the same network address. Example: `10.0.0.0/25` and `10.0.0.0/24`.
        - Must contain all IP addresses in use in the old CIDR range.
        - The new CIDR range's broadcast address (last IP address of CIDR range) must not be an IP address in use in the old CIDR range.

        **Note:** If you are changing the CIDR block, you cannot create VNICs or private IPs for this resource while the update is in progress.


        :param cidr_block: The cidr_block of this UpdateVlanDetails.
        :type: str
        """
        self._cidr_block = cidr_block

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SearchCriteria(object):
    """
    Search Query object that allows complex search predicates that cannot be expressed through simple query params.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SearchCriteria object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param query:
            The value to assign to the query property of this SearchCriteria.
        :type query: str

        :param faceted_query:
            The value to assign to the faceted_query property of this SearchCriteria.
        :type faceted_query: str

        :param dimensions:
            The value to assign to the dimensions property of this SearchCriteria.
        :type dimensions: list[str]

        :param sort:
            The value to assign to the sort property of this SearchCriteria.
        :type sort: list[oci.data_catalog.models.FacetedSearchSortRequest]

        :param filters:
            The value to assign to the filters property of this SearchCriteria.
        :type filters: oci.data_catalog.models.FacetedSearchFilterRequest

        """
        self.swagger_types = {
            'query': 'str',
            'faceted_query': 'str',
            'dimensions': 'list[str]',
            'sort': 'list[FacetedSearchSortRequest]',
            'filters': 'FacetedSearchFilterRequest'
        }

        self.attribute_map = {
            'query': 'query',
            'faceted_query': 'facetedQuery',
            'dimensions': 'dimensions',
            'sort': 'sort',
            'filters': 'filters'
        }

        self._query = None
        self._faceted_query = None
        self._dimensions = None
        self._sort = None
        self._filters = None

    @property
    def query(self):
        """
        Gets the query of this SearchCriteria.
        Search query dsl that defines the query components including fields and predicates.


        :return: The query of this SearchCriteria.
        :rtype: str
        """
        return self._query

    @query.setter
    def query(self, query):
        """
        Sets the query of this SearchCriteria.
        Search query dsl that defines the query components including fields and predicates.


        :param query: The query of this SearchCriteria.
        :type: str
        """
        self._query = query

    @property
    def faceted_query(self):
        """
        Gets the faceted_query of this SearchCriteria.
        Query string that a dataObject is to be searched with. Used in the faceted query request


        :return: The faceted_query of this SearchCriteria.
        :rtype: str
        """
        return self._faceted_query

    @faceted_query.setter
    def faceted_query(self, faceted_query):
        """
        Sets the faceted_query of this SearchCriteria.
        Query string that a dataObject is to be searched with. Used in the faceted query request


        :param faceted_query: The faceted_query of this SearchCriteria.
        :type: str
        """
        self._faceted_query = faceted_query

    @property
    def dimensions(self):
        """
        Gets the dimensions of this SearchCriteria.
        List of properties of dataObjects that needs to aggregated on for facets.


        :return: The dimensions of this SearchCriteria.
        :rtype: list[str]
        """
        return self._dimensions

    @dimensions.setter
    def dimensions(self, dimensions):
        """
        Sets the dimensions of this SearchCriteria.
        List of properties of dataObjects that needs to aggregated on for facets.


        :param dimensions: The dimensions of this SearchCriteria.
        :type: list[str]
        """
        self._dimensions = dimensions

    @property
    def sort(self):
        """
        Gets the sort of this SearchCriteria.
        Array of objects having details about sort field and order.


        :return: The sort of this SearchCriteria.
        :rtype: list[oci.data_catalog.models.FacetedSearchSortRequest]
        """
        return self._sort

    @sort.setter
    def sort(self, sort):
        """
        Sets the sort of this SearchCriteria.
        Array of objects having details about sort field and order.


        :param sort: The sort of this SearchCriteria.
        :type: list[oci.data_catalog.models.FacetedSearchSortRequest]
        """
        self._sort = sort

    @property
    def filters(self):
        """
        Gets the filters of this SearchCriteria.

        :return: The filters of this SearchCriteria.
        :rtype: oci.data_catalog.models.FacetedSearchFilterRequest
        """
        return self._filters

    @filters.setter
    def filters(self, filters):
        """
        Sets the filters of this SearchCriteria.

        :param filters: The filters of this SearchCriteria.
        :type: oci.data_catalog.models.FacetedSearchFilterRequest
        """
        self._filters = filters

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class InstanceDetails(object):
    """
    The details of the Oracle Real Application Clusters (Oracle RAC) database instance.
    """

    #: A constant which can be used with the status property of a InstanceDetails.
    #: This constant has a value of "UP"
    STATUS_UP = "UP"

    #: A constant which can be used with the status property of a InstanceDetails.
    #: This constant has a value of "DOWN"
    STATUS_DOWN = "DOWN"

    #: A constant which can be used with the status property of a InstanceDetails.
    #: This constant has a value of "UNKNOWN"
    STATUS_UNKNOWN = "UNKNOWN"

    def __init__(self, **kwargs):
        """
        Initializes a new InstanceDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this InstanceDetails.
        :type id: int

        :param name:
            The value to assign to the name property of this InstanceDetails.
        :type name: str

        :param host_name:
            The value to assign to the host_name property of this InstanceDetails.
        :type host_name: str

        :param status:
            The value to assign to the status property of this InstanceDetails.
            Allowed values for this property are: "UP", "DOWN", "UNKNOWN", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        """
        self.swagger_types = {
            'id': 'int',
            'name': 'str',
            'host_name': 'str',
            'status': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'host_name': 'hostName',
            'status': 'status'
        }

        self._id = None
        self._name = None
        self._host_name = None
        self._status = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this InstanceDetails.
        The ID of the Oracle RAC database instance.


        :return: The id of this InstanceDetails.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this InstanceDetails.
        The ID of the Oracle RAC database instance.


        :param id: The id of this InstanceDetails.
        :type: int
        """
        self._id = id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this InstanceDetails.
        The name of the Oracle RAC database instance.


        :return: The name of this InstanceDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this InstanceDetails.
        The name of the Oracle RAC database instance.


        :param name: The name of this InstanceDetails.
        :type: str
        """
        self._name = name

    @property
    def host_name(self):
        """
        **[Required]** Gets the host_name of this InstanceDetails.
        The name of the host of the Oracle RAC database instance.


        :return: The host_name of this InstanceDetails.
        :rtype: str
        """
        return self._host_name

    @host_name.setter
    def host_name(self, host_name):
        """
        Sets the host_name of this InstanceDetails.
        The name of the host of the Oracle RAC database instance.


        :param host_name: The host_name of this InstanceDetails.
        :type: str
        """
        self._host_name = host_name

    @property
    def status(self):
        """
        **[Required]** Gets the status of this InstanceDetails.
        The status of the Oracle RAC database instance.

        Allowed values for this property are: "UP", "DOWN", "UNKNOWN", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this InstanceDetails.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this InstanceDetails.
        The status of the Oracle RAC database instance.


        :param status: The status of this InstanceDetails.
        :type: str
        """
        allowed_values = ["UP", "DOWN", "UNKNOWN"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateDbSystemDetails(object):
    """
    Details required to create a DB System.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateDbSystemDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateDbSystemDetails.
        :type display_name: str

        :param description:
            The value to assign to the description property of this CreateDbSystemDetails.
        :type description: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateDbSystemDetails.
        :type compartment_id: str

        :param is_highly_available:
            The value to assign to the is_highly_available property of this CreateDbSystemDetails.
        :type is_highly_available: bool

        :param availability_domain:
            The value to assign to the availability_domain property of this CreateDbSystemDetails.
        :type availability_domain: str

        :param fault_domain:
            The value to assign to the fault_domain property of this CreateDbSystemDetails.
        :type fault_domain: str

        :param configuration_id:
            The value to assign to the configuration_id property of this CreateDbSystemDetails.
        :type configuration_id: str

        :param shape_name:
            The value to assign to the shape_name property of this CreateDbSystemDetails.
        :type shape_name: str

        :param mysql_version:
            The value to assign to the mysql_version property of this CreateDbSystemDetails.
        :type mysql_version: str

        :param subnet_id:
            The value to assign to the subnet_id property of this CreateDbSystemDetails.
        :type subnet_id: str

        :param admin_username:
            The value to assign to the admin_username property of this CreateDbSystemDetails.
        :type admin_username: str

        :param admin_password:
            The value to assign to the admin_password property of this CreateDbSystemDetails.
        :type admin_password: str

        :param data_storage_size_in_gbs:
            The value to assign to the data_storage_size_in_gbs property of this CreateDbSystemDetails.
        :type data_storage_size_in_gbs: int

        :param hostname_label:
            The value to assign to the hostname_label property of this CreateDbSystemDetails.
        :type hostname_label: str

        :param ip_address:
            The value to assign to the ip_address property of this CreateDbSystemDetails.
        :type ip_address: str

        :param port:
            The value to assign to the port property of this CreateDbSystemDetails.
        :type port: int

        :param port_x:
            The value to assign to the port_x property of this CreateDbSystemDetails.
        :type port_x: int

        :param backup_policy:
            The value to assign to the backup_policy property of this CreateDbSystemDetails.
        :type backup_policy: oci.mysql.models.CreateBackupPolicyDetails

        :param source:
            The value to assign to the source property of this CreateDbSystemDetails.
        :type source: oci.mysql.models.CreateDbSystemSourceDetails

        :param maintenance:
            The value to assign to the maintenance property of this CreateDbSystemDetails.
        :type maintenance: oci.mysql.models.CreateMaintenanceDetails

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateDbSystemDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateDbSystemDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'display_name': 'str',
            'description': 'str',
            'compartment_id': 'str',
            'is_highly_available': 'bool',
            'availability_domain': 'str',
            'fault_domain': 'str',
            'configuration_id': 'str',
            'shape_name': 'str',
            'mysql_version': 'str',
            'subnet_id': 'str',
            'admin_username': 'str',
            'admin_password': 'str',
            'data_storage_size_in_gbs': 'int',
            'hostname_label': 'str',
            'ip_address': 'str',
            'port': 'int',
            'port_x': 'int',
            'backup_policy': 'CreateBackupPolicyDetails',
            'source': 'CreateDbSystemSourceDetails',
            'maintenance': 'CreateMaintenanceDetails',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'description': 'description',
            'compartment_id': 'compartmentId',
            'is_highly_available': 'isHighlyAvailable',
            'availability_domain': 'availabilityDomain',
            'fault_domain': 'faultDomain',
            'configuration_id': 'configurationId',
            'shape_name': 'shapeName',
            'mysql_version': 'mysqlVersion',
            'subnet_id': 'subnetId',
            'admin_username': 'adminUsername',
            'admin_password': 'adminPassword',
            'data_storage_size_in_gbs': 'dataStorageSizeInGBs',
            'hostname_label': 'hostnameLabel',
            'ip_address': 'ipAddress',
            'port': 'port',
            'port_x': 'portX',
            'backup_policy': 'backupPolicy',
            'source': 'source',
            'maintenance': 'maintenance',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._display_name = None
        self._description = None
        self._compartment_id = None
        self._is_highly_available = None
        self._availability_domain = None
        self._fault_domain = None
        self._configuration_id = None
        self._shape_name = None
        self._mysql_version = None
        self._subnet_id = None
        self._admin_username = None
        self._admin_password = None
        self._data_storage_size_in_gbs = None
        self._hostname_label = None
        self._ip_address = None
        self._port = None
        self._port_x = None
        self._backup_policy = None
        self._source = None
        self._maintenance = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateDbSystemDetails.
        The user-friendly name for the DB System. It does not have to be unique.


        :return: The display_name of this CreateDbSystemDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateDbSystemDetails.
        The user-friendly name for the DB System. It does not have to be unique.


        :param display_name: The display_name of this CreateDbSystemDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this CreateDbSystemDetails.
        User-provided data about the DB System.


        :return: The description of this CreateDbSystemDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateDbSystemDetails.
        User-provided data about the DB System.


        :param description: The description of this CreateDbSystemDetails.
        :type: str
        """
        self._description = description

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateDbSystemDetails.
        The OCID of the compartment.


        :return: The compartment_id of this CreateDbSystemDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateDbSystemDetails.
        The OCID of the compartment.


        :param compartment_id: The compartment_id of this CreateDbSystemDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def is_highly_available(self):
        """
        Gets the is_highly_available of this CreateDbSystemDetails.
        Specifies if the DB System is highly available.

        When creating a DB System with High Availability, three instances
        are created and placed according to your region- and
        subnet-type. The secondaries are placed automatically in the other
        two availability or fault domains.  You can choose the preferred
        location of your primary instance, only.


        :return: The is_highly_available of this CreateDbSystemDetails.
        :rtype: bool
        """
        return self._is_highly_available

    @is_highly_available.setter
    def is_highly_available(self, is_highly_available):
        """
        Sets the is_highly_available of this CreateDbSystemDetails.
        Specifies if the DB System is highly available.

        When creating a DB System with High Availability, three instances
        are created and placed according to your region- and
        subnet-type. The secondaries are placed automatically in the other
        two availability or fault domains.  You can choose the preferred
        location of your primary instance, only.


        :param is_highly_available: The is_highly_available of this CreateDbSystemDetails.
        :type: bool
        """
        self._is_highly_available = is_highly_available

    @property
    def availability_domain(self):
        """
        Gets the availability_domain of this CreateDbSystemDetails.
        The availability domain on which to deploy the Read/Write endpoint. This defines the preferred primary instance.

        In a failover scenario, the Read/Write endpoint is redirected to one of the other availability domains
        and the MySQL instance in that domain is promoted to the primary instance.
        This redirection does not affect the IP address of the DB System in any way.

        For a standalone DB System, this defines the availability domain in which the DB System is placed.


        :return: The availability_domain of this CreateDbSystemDetails.
        :rtype: str
        """
        return self._availability_domain

    @availability_domain.setter
    def availability_domain(self, availability_domain):
        """
        Sets the availability_domain of this CreateDbSystemDetails.
        The availability domain on which to deploy the Read/Write endpoint. This defines the preferred primary instance.

        In a failover scenario, the Read/Write endpoint is redirected to one of the other availability domains
        and the MySQL instance in that domain is promoted to the primary instance.
        This redirection does not affect the IP address of the DB System in any way.

        For a standalone DB System, this defines the availability domain in which the DB System is placed.


        :param availability_domain: The availability_domain of this CreateDbSystemDetails.
        :type: str
        """
        self._availability_domain = availability_domain

    @property
    def fault_domain(self):
        """
        Gets the fault_domain of this CreateDbSystemDetails.
        The fault domain on which to deploy the Read/Write endpoint. This defines the preferred primary instance.

        In a failover scenario, the Read/Write endpoint is redirected to one of the other fault domains
        and the MySQL instance in that domain is promoted to the primary instance.
        This redirection does not affect the IP address of the DB System in any way.

        For a standalone DB System, this defines the fault domain in which the DB System is placed.


        :return: The fault_domain of this CreateDbSystemDetails.
        :rtype: str
        """
        return self._fault_domain

    @fault_domain.setter
    def fault_domain(self, fault_domain):
        """
        Sets the fault_domain of this CreateDbSystemDetails.
        The fault domain on which to deploy the Read/Write endpoint. This defines the preferred primary instance.

        In a failover scenario, the Read/Write endpoint is redirected to one of the other fault domains
        and the MySQL instance in that domain is promoted to the primary instance.
        This redirection does not affect the IP address of the DB System in any way.

        For a standalone DB System, this defines the fault domain in which the DB System is placed.


        :param fault_domain: The fault_domain of this CreateDbSystemDetails.
        :type: str
        """
        self._fault_domain = fault_domain

    @property
    def configuration_id(self):
        """
        Gets the configuration_id of this CreateDbSystemDetails.
        The OCID of the Configuration to be used for this DB System.


        :return: The configuration_id of this CreateDbSystemDetails.
        :rtype: str
        """
        return self._configuration_id

    @configuration_id.setter
    def configuration_id(self, configuration_id):
        """
        Sets the configuration_id of this CreateDbSystemDetails.
        The OCID of the Configuration to be used for this DB System.


        :param configuration_id: The configuration_id of this CreateDbSystemDetails.
        :type: str
        """
        self._configuration_id = configuration_id

    @property
    def shape_name(self):
        """
        **[Required]** Gets the shape_name of this CreateDbSystemDetails.
        The name of the shape. The shape determines the resources allocated
        - CPU cores and memory for VM shapes; CPU cores, memory and storage
        for non-VM (or bare metal) shapes. To get a list of shapes, use the
        :func:`list_shapes` operation.


        :return: The shape_name of this CreateDbSystemDetails.
        :rtype: str
        """
        return self._shape_name

    @shape_name.setter
    def shape_name(self, shape_name):
        """
        Sets the shape_name of this CreateDbSystemDetails.
        The name of the shape. The shape determines the resources allocated
        - CPU cores and memory for VM shapes; CPU cores, memory and storage
        for non-VM (or bare metal) shapes. To get a list of shapes, use the
        :func:`list_shapes` operation.


        :param shape_name: The shape_name of this CreateDbSystemDetails.
        :type: str
        """
        self._shape_name = shape_name

    @property
    def mysql_version(self):
        """
        Gets the mysql_version of this CreateDbSystemDetails.
        The specific MySQL version identifier.


        :return: The mysql_version of this CreateDbSystemDetails.
        :rtype: str
        """
        return self._mysql_version

    @mysql_version.setter
    def mysql_version(self, mysql_version):
        """
        Sets the mysql_version of this CreateDbSystemDetails.
        The specific MySQL version identifier.


        :param mysql_version: The mysql_version of this CreateDbSystemDetails.
        :type: str
        """
        self._mysql_version = mysql_version

    @property
    def subnet_id(self):
        """
        **[Required]** Gets the subnet_id of this CreateDbSystemDetails.
        The OCID of the subnet the DB System is associated with.


        :return: The subnet_id of this CreateDbSystemDetails.
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """
        Sets the subnet_id of this CreateDbSystemDetails.
        The OCID of the subnet the DB System is associated with.


        :param subnet_id: The subnet_id of this CreateDbSystemDetails.
        :type: str
        """
        self._subnet_id = subnet_id

    @property
    def admin_username(self):
        """
        **[Required]** Gets the admin_username of this CreateDbSystemDetails.
        The username for the administrative user.


        :return: The admin_username of this CreateDbSystemDetails.
        :rtype: str
        """
        return self._admin_username

    @admin_username.setter
    def admin_username(self, admin_username):
        """
        Sets the admin_username of this CreateDbSystemDetails.
        The username for the administrative user.


        :param admin_username: The admin_username of this CreateDbSystemDetails.
        :type: str
        """
        self._admin_username = admin_username

    @property
    def admin_password(self):
        """
        **[Required]** Gets the admin_password of this CreateDbSystemDetails.
        The password for the administrative user. The password must be
        between 8 and 32 characters long, and must contain at least 1
        numeric character, 1 lowercase character, 1 uppercase character, and
        1 special (nonalphanumeric) character.


        :return: The admin_password of this CreateDbSystemDetails.
        :rtype: str
        """
        return self._admin_password

    @admin_password.setter
    def admin_password(self, admin_password):
        """
        Sets the admin_password of this CreateDbSystemDetails.
        The password for the administrative user. The password must be
        between 8 and 32 characters long, and must contain at least 1
        numeric character, 1 lowercase character, 1 uppercase character, and
        1 special (nonalphanumeric) character.


        :param admin_password: The admin_password of this CreateDbSystemDetails.
        :type: str
        """
        self._admin_password = admin_password

    @property
    def data_storage_size_in_gbs(self):
        """
        Gets the data_storage_size_in_gbs of this CreateDbSystemDetails.
        Initial size of the data volume in GBs that will be created and attached.
        Keep in mind that this only specifies the size of the database data volume,
        the log volume for the database will be scaled appropriately with its shape.


        :return: The data_storage_size_in_gbs of this CreateDbSystemDetails.
        :rtype: int
        """
        return self._data_storage_size_in_gbs

    @data_storage_size_in_gbs.setter
    def data_storage_size_in_gbs(self, data_storage_size_in_gbs):
        """
        Sets the data_storage_size_in_gbs of this CreateDbSystemDetails.
        Initial size of the data volume in GBs that will be created and attached.
        Keep in mind that this only specifies the size of the database data volume,
        the log volume for the database will be scaled appropriately with its shape.


        :param data_storage_size_in_gbs: The data_storage_size_in_gbs of this CreateDbSystemDetails.
        :type: int
        """
        self._data_storage_size_in_gbs = data_storage_size_in_gbs

    @property
    def hostname_label(self):
        """
        Gets the hostname_label of this CreateDbSystemDetails.
        The hostname for the primary endpoint of the DB System. Used for DNS.

        The value is the hostname portion of the primary private IP's fully qualified domain name (FQDN)
        (for example, \"dbsystem-1\" in FQDN \"dbsystem-1.subnet123.vcn1.oraclevcn.com\").

        Must be unique across all VNICs in the subnet and comply with RFC 952 and RFC 1123.


        :return: The hostname_label of this CreateDbSystemDetails.
        :rtype: str
        """
        return self._hostname_label

    @hostname_label.setter
    def hostname_label(self, hostname_label):
        """
        Sets the hostname_label of this CreateDbSystemDetails.
        The hostname for the primary endpoint of the DB System. Used for DNS.

        The value is the hostname portion of the primary private IP's fully qualified domain name (FQDN)
        (for example, \"dbsystem-1\" in FQDN \"dbsystem-1.subnet123.vcn1.oraclevcn.com\").

        Must be unique across all VNICs in the subnet and comply with RFC 952 and RFC 1123.


        :param hostname_label: The hostname_label of this CreateDbSystemDetails.
        :type: str
        """
        self._hostname_label = hostname_label

    @property
    def ip_address(self):
        """
        Gets the ip_address of this CreateDbSystemDetails.
        The IP address the DB System is configured to listen on.
        A private IP address of your choice to assign to the primary endpoint of the DB System.
        Must be an available IP address within the subnet's CIDR. If you don't specify a value,
        Oracle automatically assigns a private IP address from the subnet. This should be a
        \"dotted-quad\" style IPv4 address.


        :return: The ip_address of this CreateDbSystemDetails.
        :rtype: str
        """
        return self._ip_address

    @ip_address.setter
    def ip_address(self, ip_address):
        """
        Sets the ip_address of this CreateDbSystemDetails.
        The IP address the DB System is configured to listen on.
        A private IP address of your choice to assign to the primary endpoint of the DB System.
        Must be an available IP address within the subnet's CIDR. If you don't specify a value,
        Oracle automatically assigns a private IP address from the subnet. This should be a
        \"dotted-quad\" style IPv4 address.


        :param ip_address: The ip_address of this CreateDbSystemDetails.
        :type: str
        """
        self._ip_address = ip_address

    @property
    def port(self):
        """
        Gets the port of this CreateDbSystemDetails.
        The port for primary endpoint of the DB System to listen on.


        :return: The port of this CreateDbSystemDetails.
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """
        Sets the port of this CreateDbSystemDetails.
        The port for primary endpoint of the DB System to listen on.


        :param port: The port of this CreateDbSystemDetails.
        :type: int
        """
        self._port = port

    @property
    def port_x(self):
        """
        Gets the port_x of this CreateDbSystemDetails.
        The TCP network port on which X Plugin listens for connections. This is the X Plugin equivalent of port.


        :return: The port_x of this CreateDbSystemDetails.
        :rtype: int
        """
        return self._port_x

    @port_x.setter
    def port_x(self, port_x):
        """
        Sets the port_x of this CreateDbSystemDetails.
        The TCP network port on which X Plugin listens for connections. This is the X Plugin equivalent of port.


        :param port_x: The port_x of this CreateDbSystemDetails.
        :type: int
        """
        self._port_x = port_x

    @property
    def backup_policy(self):
        """
        Gets the backup_policy of this CreateDbSystemDetails.

        :return: The backup_policy of this CreateDbSystemDetails.
        :rtype: oci.mysql.models.CreateBackupPolicyDetails
        """
        return self._backup_policy

    @backup_policy.setter
    def backup_policy(self, backup_policy):
        """
        Sets the backup_policy of this CreateDbSystemDetails.

        :param backup_policy: The backup_policy of this CreateDbSystemDetails.
        :type: oci.mysql.models.CreateBackupPolicyDetails
        """
        self._backup_policy = backup_policy

    @property
    def source(self):
        """
        Gets the source of this CreateDbSystemDetails.

        :return: The source of this CreateDbSystemDetails.
        :rtype: oci.mysql.models.CreateDbSystemSourceDetails
        """
        return self._source

    @source.setter
    def source(self, source):
        """
        Sets the source of this CreateDbSystemDetails.

        :param source: The source of this CreateDbSystemDetails.
        :type: oci.mysql.models.CreateDbSystemSourceDetails
        """
        self._source = source

    @property
    def maintenance(self):
        """
        Gets the maintenance of this CreateDbSystemDetails.

        :return: The maintenance of this CreateDbSystemDetails.
        :rtype: oci.mysql.models.CreateMaintenanceDetails
        """
        return self._maintenance

    @maintenance.setter
    def maintenance(self, maintenance):
        """
        Sets the maintenance of this CreateDbSystemDetails.

        :param maintenance: The maintenance of this CreateDbSystemDetails.
        :type: oci.mysql.models.CreateMaintenanceDetails
        """
        self._maintenance = maintenance

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateDbSystemDetails.
        Simple key-value pair applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this CreateDbSystemDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateDbSystemDetails.
        Simple key-value pair applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this CreateDbSystemDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateDbSystemDetails.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this CreateDbSystemDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateDbSystemDetails.
        Usage of predefined tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this CreateDbSystemDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PoliticalLocation(object):
    """
    Political location of a problem
    """

    def __init__(self, **kwargs):
        """
        Initializes a new PoliticalLocation object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param city:
            The value to assign to the city property of this PoliticalLocation.
        :type city: str

        :param state:
            The value to assign to the state property of this PoliticalLocation.
        :type state: str

        :param country:
            The value to assign to the country property of this PoliticalLocation.
        :type country: str

        """
        self.swagger_types = {
            'city': 'str',
            'state': 'str',
            'country': 'str'
        }

        self.attribute_map = {
            'city': 'city',
            'state': 'state',
            'country': 'country'
        }

        self._city = None
        self._state = None
        self._country = None

    @property
    def city(self):
        """
        **[Required]** Gets the city of this PoliticalLocation.
        City


        :return: The city of this PoliticalLocation.
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """
        Sets the city of this PoliticalLocation.
        City


        :param city: The city of this PoliticalLocation.
        :type: str
        """
        self._city = city

    @property
    def state(self):
        """
        **[Required]** Gets the state of this PoliticalLocation.
        State


        :return: The state of this PoliticalLocation.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this PoliticalLocation.
        State


        :param state: The state of this PoliticalLocation.
        :type: str
        """
        self._state = state

    @property
    def country(self):
        """
        **[Required]** Gets the country of this PoliticalLocation.
        Country


        :return: The country of this PoliticalLocation.
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """
        Sets the country of this PoliticalLocation.
        Country


        :param country: The country of this PoliticalLocation.
        :type: str
        """
        self._country = country

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AutonomousDatabaseApex(object):
    """
    Oracle APEX Application Development is a low-code development platform that enables you to build scalable, secure enterprise apps, with world-class features. Autonomous Database with the APEX workload type is optimized to support APEX development.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AutonomousDatabaseApex object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param apex_version:
            The value to assign to the apex_version property of this AutonomousDatabaseApex.
        :type apex_version: str

        :param ords_version:
            The value to assign to the ords_version property of this AutonomousDatabaseApex.
        :type ords_version: str

        """
        self.swagger_types = {
            'apex_version': 'str',
            'ords_version': 'str'
        }

        self.attribute_map = {
            'apex_version': 'apexVersion',
            'ords_version': 'ordsVersion'
        }

        self._apex_version = None
        self._ords_version = None

    @property
    def apex_version(self):
        """
        Gets the apex_version of this AutonomousDatabaseApex.
        The Oracle APEX Application Development version.


        :return: The apex_version of this AutonomousDatabaseApex.
        :rtype: str
        """
        return self._apex_version

    @apex_version.setter
    def apex_version(self, apex_version):
        """
        Sets the apex_version of this AutonomousDatabaseApex.
        The Oracle APEX Application Development version.


        :param apex_version: The apex_version of this AutonomousDatabaseApex.
        :type: str
        """
        self._apex_version = apex_version

    @property
    def ords_version(self):
        """
        Gets the ords_version of this AutonomousDatabaseApex.
        The Oracle REST Data Services (ORDS) version.


        :return: The ords_version of this AutonomousDatabaseApex.
        :rtype: str
        """
        return self._ords_version

    @ords_version.setter
    def ords_version(self, ords_version):
        """
        Sets the ords_version of this AutonomousDatabaseApex.
        The Oracle REST Data Services (ORDS) version.


        :param ords_version: The ords_version of this AutonomousDatabaseApex.
        :type: str
        """
        self._ords_version = ords_version

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
